@@ -57,7 +57,7 @@ class DatoMapper(object):
             sample_percent: the sampling ratio; 1 (100%) by default.
             title: the name of the created task in Datomize; "sdk_flow" by default.
             wait: use wait=False for asynchronous programming; True by default (awaits for the results)."""
-        self.create_datasource(path, df, df_name if df_name else title)
+        self.create_datasource(path, df, df_name if df_name else "temp_sdk")
 
         self.pre_run_validation()
         self.flow_id = autodiscovery_helper.discover(self.datomizer,
